[movitz-cvs] CVS update: movitz/special-operators.lisp

Frode Vatvedt Fjeld ffjeld at common-lisp.net
Wed Mar 31 16:33:25 UTC 2004


Update of /project/movitz/cvsroot/movitz
In directory common-lisp.net:/tmp/cvs-serv2537

Modified Files:
	special-operators.lisp 
Log Message:
Minor edits.

Date: Wed Mar 31 11:33:25 2004
Author: ffjeld

Index: movitz/special-operators.lisp
diff -u movitz/special-operators.lisp:1.16 movitz/special-operators.lisp:1.17
--- movitz/special-operators.lisp:1.16	Sun Mar 28 11:20:05 2004
+++ movitz/special-operators.lisp	Wed Mar 31 11:33:25 2004
@@ -8,7 +8,7 @@
 ;;;; Author:        Frode Vatvedt Fjeld <frodef at acm.org>
 ;;;; Created at:    Fri Nov 24 16:22:59 2000
 ;;;;                
-;;;; $Id: special-operators.lisp,v 1.16 2004/03/28 16:20:05 ffjeld Exp $
+;;;; $Id: special-operators.lisp,v 1.17 2004/03/31 16:33:25 ffjeld Exp $
 ;;;;                
 ;;;;------------------------------------------------------------------
 
@@ -377,7 +377,7 @@
 					       :muerte.cl :cl))
 	    (cl-macro-body (translate-program macro-body :muerte.cl :cl)))
 	(when (member name (image-called-functions *image*) :key #'first)
 	  #+ignore (warn "Macro ~S defined after being called as function (in ~S)."
 			 name
 			 (cdr (find name (image-called-functions *image*) :key #'first))))
 	(multiple-value-bind (cl-body declarations doc-string)
@@ -427,7 +427,7 @@
 		(env-formal (or envvar (gensym)))
 		(expansion-var (gensym)))
 	    (when (member operator-name (image-called-functions *image*) :key #'first)
-	      (warn "Compiler-macro ~S defined after being called as function (in ~S)"
+	      (warn "Compiler-macro ~S defined after being called as function (first in ~S)"
 		    operator-name
 		    (cdr (find operator-name (image-called-functions *image*) :key #'first))))
 	    (let ((expander
@@ -572,7 +572,7 @@
 			   (destructuring-bind (var)
 			       (cdr expr)
 			     (let ((binding (movitz-binding var env)))
-			       (check-type binding lexical-binding)
+			       (check-type binding binding)
 			       (list binding)))))
 		       (let ((code (assembly-macroexpand inline-asm amenv)))
 			 #+ignore
@@ -686,7 +686,7 @@
 			       `((:cmpl :edi ,(single-value-register not-returns))))
 		 :returns :boolean-zf=1)) ; TRUE iff result equal to :edi/NIL.
 	      (otherwise
-	       (warn "unable to deal inteligently with inlined-NOT not-returns: ~S for ~S from ~S"
+	       (warn "unable to deal intelligently with inlined-NOT not-returns: ~S for ~S from ~S"
 		     not-returns not-result-mode (not-values :producer))
 	       (let ((label (make-symbol "not-label")))
 		 (compiler-values (not-values)
@@ -711,9 +711,9 @@
 	as sub-form-result-mode = buried-result-modes
 	then (or (cdr sub-form-result-mode)
 		 sub-form-result-mode)
-	as current-result-mode = (if (endp (cdr sub-form))
-				     ;; all but the last form have
-				     ;; result-mode as declared
+	as current-result-mode = (if (endp (cdr sub-form)) all but the
+				     ;; last form have result-mode as
+				     ;; declared
 				     result-mode
 				   (car sub-form-result-mode))
 	as last-form-p = (endp (cdr sub-form))
@@ -377,7 +377,7 @@
 	    (cl-macro-body (translate-program macro-body :muerte.cl :cl)))
 	(when (member name (image-called-functions *image*) :key #'first)
-	  #+ignore (warn "Macro ~S defined after being called as function (in ~S)."
+	  #+ignore (warn "Macro ~S defined after being called as function (first in ~S)."
 			 name
 			 (cdr (find name (image-called-functions *image*) :key #'first))))





More information about the Movitz-cvs mailing list